==> rapid_widgets_library-0.1.1.tar.gz: lib/custom-progress-card.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:rapid_widgets_library/widget-classesUsed.dart';
import 'package:rapid_widgets_library/custom-linearProgressIndicator.dart';

Widget customProgressCard(
    MaterialCardData data, Function(String, int) callback) {
  CustomLinearProgressBarParameters linearBarParameters =
      new CustomLinearProgressBarParameters(
          value: 0.4,
          backgroundColor: Color(0xffE6E6E6),
          valueColor: AlwaysStoppedAnimation<Color>(Color(0xff00AA0B)));

  return Container(
    height: (data.containerHeight != null) ? data.containerHeight : 300,
    width: (data.containerWidth != null) ? data.containerWidth : 354,
    decoration: (data.containerDecoration != null)
        ? data.containerDecoration
        : BoxDecoration(
            boxShadow: <BoxShadow>[
              BoxShadow(
                color: Color(0xff00002e),
                offset: Offset(0.0, 2.0),
                blurRadius: 6.0,
              ),
            ],
            color: Colors.white,
            borderRadius: BorderRadius.circular(12),
            border: Border.all(
              color: Color(0xffE9E9E9),
              width: 1,
            ),
          ),
    child: Padding(
      padding: const EdgeInsets.only(left: 10.0),
      child: Column(
        children: <Widget>[
          Align(
            alignment: Alignment.centerLeft,
            child: Padding(
              padding: const EdgeInsets.only(top: 16.2),
              child: (data.title != null)
                  ? data.title
                  : Text(
                      'Programming with JavaScript',
                      style: TextStyle(
                          fontSize: 16.0,
                          color: Color(0xffD93954),
                          fontFamily: 'Georgia'),
                    ),
            ),
          ),
          Align(
            alignment: Alignment.centerLeft,
            child: Padding(
              padding: const EdgeInsets.only(top: 9.0),
              child: (data.subtitle != null)
                  ? data.subtitle
                  : Text(
                      'Chapter 3 - The Period',
                      style: TextStyle(
                          fontSize: 20.0,
                          color: Color(0xff707070),
                          fontFamily: 'Georgia'),
                    ),
            ),
          ),
          Align(
            alignment: Alignment.centerLeft,
            child: Padding(
              padding: const EdgeInsets.only(top: 21.0),
              child: (data.bodyText != null)
                  ? data.bodyText
                  : Text(
                      'JavaScript is a powerful and versatile scripting language used in web applic...',
                      style: TextStyle(
                          fontSize: 16.0,
                          color: Color(0xff707070),
                          fontFamily: 'Segoe UI'),
                    ),
            ),
          ),
          Align(
            alignment: Alignment.centerRight,
            child: Padding(
              padding: const EdgeInsets.only(top: 15.0, right: 18.0),
              child: (data.btnGrpList1 != null)
                  ? data.btnGrpList1
                  : FlatButton(
                      shape: new RoundedRectangleBorder(
                          borderRadius: new BorderRadius.circular(30.0)),
                      disabledColor: Color(0xffD93954),
                      color: Color(0xffD93954),
                      child: Text(
                        'Continue Course',
                        style: TextStyle(
                            fontFamily: 'Segoe UI',
                            fontSize: 12.0,
                            color: Colors.white),
                      ),
                      onPressed: () {},
                    ),
            ),
          ),
          Align(
            alignment: Alignment.centerLeft,
            child: Padding(
              padding: const EdgeInsets.only(top: 2.0),
              child: (data.footerText != null)
                  ? data.footerText
                  : Text(
                      'Progress',
                      style: TextStyle(
                          fontSize: 14.0,
                          color: Color(0xff707070),
                          fontFamily: 'Segoe UI'),
                    ),
            ),
          ),
          Align(
            alignment: Alignment.centerLeft,
            child: Padding(
              padding: const EdgeInsets.only(top: 2.0),
              child: (data.btnGrpList2 != null)
                  ? data.btnGrpList2
                  : customLinearProgressBarIndicator(linearBarParameters),
            ),
          ),
        ],
      ),
    ),
  );
}

==> rapid_widgets_library-0.1.2.tar.gz: lib/custom-progress-card.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:rapid_widgets_library/widget-classesUsed.dart';
import 'package:rapid_widgets_library/custom-linearProgressIndicator.dart';

Widget customProgressCard(
    MaterialCardData data, Function(String, int) callback) {
  CustomLinearProgressBarParameters linearBarParameters =
      new CustomLinearProgressBarParameters(
          value: 0.4,
          backgroundColor: Color(0xffE6E6E6),
          valueColor: AlwaysStoppedAnimation<Color>(Color(0xff00AA0B)));

  return Container(
    height: (data.containerHeight != null) ? data.containerHeight : 300,
    width: (data.containerWidth != null) ? data.containerWidth : 354,
    decoration: (data.containerDecoration != null)
        ? data.containerDecoration
        : BoxDecoration(
            boxShadow: <BoxShadow>[
              BoxShadow(
                color: Color(0xff00002e),
                offset: Offset(0.0, 2.0),
                blurRadius: 6.0,
              ),
            ],
            color: Colors.white,
            borderRadius: BorderRadius.circular(12),
            border: Border.all(
              color: Color(0xffE9E9E9),
              width: 1,
            ),
          ),
    child: Padding(
      padding: const EdgeInsets.only(left: 10.0),
      child: Column(
        children: <Widget>[
          Align(
            alignment: Alignment.centerLeft,
            child: Padding(
              padding: const EdgeInsets.only(top: 16.2),
              child: Text(
                (data.title != null)
                    ? data.title
                    : 'Programming with JavaScript',
                style: (data.textStyle1 != null)
                    ? data.textStyle1
                    : TextStyle(
                        fontSize: 16.0,
                        color: Color(0xffD93954),
                        fontFamily: 'Georgia'),
              ),
            ),
          ),
          Align(
            alignment: Alignment.centerLeft,
            child: Padding(
              padding: const EdgeInsets.only(top: 9.0),
              child: Text(
                (data.subtitle != null)
                    ? data.subtitle
                    : 'Chapter 3 - The Period',
                style: (data.textStyle2 != null)
                    ? data.textStyle2
                    : TextStyle(
                        fontSize: 20.0,
                        color: Color(0xff707070),
                        fontFamily: 'Georgia'),
              ),
            ),
          ),
          Align(
            alignment: Alignment.centerLeft,
            child: Padding(
              padding: const EdgeInsets.only(top: 21.0),
              child: Text(
                (data.bodyText != null)
                    ? data.bodyText
                    : 'JavaScript is a powerful and versatile scripting language used in web applic...',
                style: (data.textStyle3 != null)
                    ? data.textStyle3
                    : TextStyle(
                        fontSize: 16.0,
                        color: Color(0xff707070),
                        fontFamily: 'Segoe UI'),
              ),
            ),
          ),
          Align(
            alignment: Alignment.centerRight,
            child: Padding(
              padding: const EdgeInsets.only(top: 15.0, right: 18.0),
              child: (data.btnGrpList1 != null)
                  ? data.btnGrpList1
                  : FlatButton(
                      shape: new RoundedRectangleBorder(
                          borderRadius: new BorderRadius.circular(30.0)),
                      disabledColor: Color(0xffD93954),
                      color: Color(0xffD93954),
                      child: Text(
                        'Continue Course',
                        style: TextStyle(
                            fontFamily: 'Segoe UI',
                            fontSize: 12.0,
                            color: Colors.white),
                      ),
                      onPressed: () {},
                    ),
            ),
          ),
          Align(
            alignment: Alignment.centerLeft,
            child: Padding(
              padding: const EdgeInsets.only(top: 2.0),
              child: Text(
                (data.footerText != null) ? data.footerText : 'Progress',
                style: (data.textStyle4 != null)
                    ? data.textStyle4
                    : TextStyle(
                        fontSize: 14.0,
                        color: Color(0xff707070),
                        fontFamily: 'Segoe UI'),
              ),
            ),
          ),
          Align(
            alignment: Alignment.centerLeft,
            child: Padding(
              padding: const EdgeInsets.only(top: 2.0),
              child: (data.btnGrpList2 != null)
                  ? data.btnGrpList2
                  : customLinearProgressBarIndicator(linearBarParameters),
            ),
          ),
        ],
      ),
    ),
  );
}
